#!/bin/sh
#
#  Adds a drwatson message
#
#  Author:  Tamas Nemeth <tnemeth@imagemedical.com>
#  Created: Aug 14. 2001
#
#  addmessage.sh checks if the message has been already sent, and sends only if the message is new.
#
#  usage:
#         addmessage.sh [-i <message ID>] [-t <message type>] [-l <message level>] <message>
#
#   message ID    : ID for the message. addmessage.sh check this for already sent messages
#   message type  : ERROR (default) | WARNING | READY
#   message level : Where to create the flag file. Only takes effect if message ID is given
#                     NONE: Don't create flag file, the same message can be sent even immediately
#                           The same happens if message ID is missing.
#                     TMP : Create the flag file in TMP, the flag will be expired after 3 days (default)
#                     VAR : Create the flag file in VAR, only a READY message expires the flag.
#   message       : The message text to send
#

. $HOME/etc/setenv.sh

LOGGER="/usr/bin/logger"
TAG="drwatson_addmessage[$$]"

usage_()
{
  EXIT_CODE=$1
  cat << ENDOFUSAGE
Adds a drwatson message
addmessage.sh checks if the message has been already sent,
and sends only if the message is new one.

usage:
       addmessage.sh [-i <ID>] [-t <type>] [-l <level>] <message>

ID      : Message ID, addmessage.sh check this for already sent messages
type    : ERROR (default) | WARNING | READY
level   : Where to create the flag file. Only takes effect if message ID is
          given. Possible values:
            NONE: Don't create flag file, the same message can be sent even
                  immediately. The same happens if message ID is missing.
            TMP : Create the flag file in TMP, the flag will be expired after
                  3 days (default)
            VAR : Create the flag file in VAR, only a READY message expires
                  the flag.
message : The message text to send
ENDOFUSAGE

  exit $EXIT_CODE
}

MESSAGE_ID=""
MESSAGE_TEXT=""
MESSAGE_TYPE="ERROR"
MESSAGE_LEVEL="TMP"
MESSAGE_TEXT=""

while getopts 'i:t:l:' OPT; do
  case $OPT in
  i) MESSAGE_ID="$OPTARG" ;;
  t) MESSAGE_TYPE="$OPTARG" ;;
  l) MESSAGE_LEVEL="$OPTARG" ;;   
  *) usage 1 ;;
  esac
done  

shift $(($OPTIND-1))

MESSAGE_TEXT="$1"

[ -z "$MESSAGE_TEXT" ] && usage_ 1

MESSAGE_FLAG_FILE=""

[ "TMP" = "$MESSAGE_LEVEL" ] && MESSAGE_FLAG_FILE=$TMP/$MESSAGE_ID
[ "VAR" = "$MESSAGE_LEVEL" ] && MESSAGE_FLAG_FILE=$DRWATSON_FILES/$MESSAGE_ID

MESSAGE_FILE=$DRWATSON_ERROR_FILE

[ "WARNING" = "$MESSAGE_TYPE" ] && MESSAGE_FILE=$DRWATSON_WARNING_FILE
[ "READY" = "$MESSAGE_TYPE" ] && MESSAGE_FILE=$DRWATSON_READY_FILE


if [ -z "$MESSAGE_ID" -o -z "$MESSAGE_FLAG_FILE" ] ; then
  $LOGGER -p $LOG_FACILITY.err -t "$TAG" "$MESSAGE_TEXT"
  echo "$MESSAGE_TEXT" >> $MESSAGE_FILE
  exit
fi


if [ "$MESSAGE_TYPE" = "READY" ] ; then
  if [ -f "$MESSAGE_FLAG_FILE" ] ; then
    rm $MESSAGE_FLAG_FILE
    $LOGGER -p $LOG_FACILITY.err -t "$TAG" "$MESSAGE_TEXT"
    echo "$MESSAGE_TEXT" >> $MESSAGE_FILE
  fi

  exit
fi


if [ ! -f "$MESSAGE_FLAG_FILE" ] ; then
  > $MESSAGE_FLAG_FILE
  $LOGGER -p $LOG_FACILITY.err -t "$TAG" "$MESSAGE_TEXT"
  echo "$MESSAGE_TEXT" >> $MESSAGE_FILE
fi
